#include "gtest/gtest.h"

#include "XTime.h"

void test_lib ( const char* time_in,
		const char* ts_in,
		const char* tf_in,
		const char* mjdi,
		const char* mjdf,
		const char* ts_out,
		const char* tf_out,
		const char* exp
		) {


    {
	char output[256];

	ASSERT_EQ( 0,
		   axTime3( time_in, ts_in, tf_in,
			    ts_out, tf_out,
			    output,
			    mjdi, mjdf
			    )
		   );

	EXPECT_STREQ( exp, output ) ;

    }

    {
	char output[256];
	char const* argv[8];
	int argc = 0;
	argv[++argc] = time_in;
	argv[++argc] = ts_in;
	argv[++argc] = tf_in;
	argv[++argc] = mjdi;
	argv[++argc] = mjdf;
	argv[++argc] = ts_out;
	argv[++argc] = tf_out;

	ASSERT_EQ( 0,  axTime3( argc + 1, argv, output ) );

	EXPECT_STREQ( exp, output ) ;
    }

}

void test_lib ( const char* time_in,
		const char* ts_in,
		const char* tf_in,
		const char* ts_out,
		const char* tf_out,
		const char* exp
		) {


    {
	char output[256];

	ASSERT_EQ( 0,
		   axTime3( time_in, ts_in, tf_in,
			    ts_out, tf_out,
			    output
			    )
		   );

	EXPECT_STREQ( exp, output ) ;

    }

    {
	char output[256];
	char const* argv[6];
	int argc = 0;
	argv[++argc] = time_in;
	argv[++argc] = ts_in;
	argv[++argc] = tf_in;
	argv[++argc] = ts_out;
	argv[++argc] = tf_out;

	ASSERT_EQ( 0,  axTime3( argc + 1, argv, output ) );

	EXPECT_STREQ( exp, output ) ;
    }

}


TEST ( TestLib, t_f3 ) {

    {
	SCOPED_TRACE( "" );
	test_lib( "1998-12-14T05:18:56.816", "t", "f3", "m", "s3", "29999936.816" );
    }


    {
	SCOPED_TRACE( "" );
	test_lib( "1998-12-14T05:18:56.816", "t", "f3", "u", "d3", "1998:348:05:17:53.632");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "1998-12-14T05:18:56.816", "t", "f3", "t", "f3", "1998-12-14T05:18:56.816");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2451161.5", "u", "j", "m", "s3", "29980863.184");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2451161.5", "u", "j", "u", "c3", "1998Dec14 at 00:00:00.000");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2451161.5", "u", "j", "u", "n3", "347:0:1:3.184");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2500000.1", "u", "j", "t", "f3", "2132-08-30T14:25:08.184");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "51160.9996275", "t", "m", "a", "c3", "1998Dec13 at 23:58:55.632");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "313996801", "m", "s", "m", "s1", "313996801.0");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "313996801", "m", "s", "t", "f3", "2007-12-14T05:20:01.000");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "1999:012:01:02:03.45", "u", "d", "u", "s3", "32490186.634");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2012-06-30T23:59:58.5", "u", "f", "t", "s3", "457488064.684");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2012-06-30T23:59:59.5", "u", "f", "t", "s3", "457488065.684");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2012-06-30T23:59:60.5", "u", "f", "t", "s3", "457488066.684");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2012-07-01T00:00:00.5", "u", "f", "t", "s3", "457488067.684");
    }

    {
	SCOPED_TRACE( "" );
	test_lib( "2012-07-01T00:00:01.5", "u", "f", "t", "s3", "457488068.684");
    }


}

